@@ -4,8 +4,8 @@ package Dist::Zilla::Plugin::OptionalFeature;
 BEGIN {
   $Dist::Zilla::Plugin::OptionalFeature::AUTHORITY = 'cpan:ETHER';
 }
-# git description: v0.009-2-g81329aa
-$Dist::Zilla::Plugin::OptionalFeature::VERSION = '0.010';
+# git description: v0.010-1-gd50fb3b
+$Dist::Zilla::Plugin::OptionalFeature::VERSION = '0.011';
 # ABSTRACT: Specify prerequisites for optional features in your dist
 # vim: set ts=8 sw=4 tw=78 et :
 
@@ -34,6 +34,11 @@ has always_recommend => (
     predicate => '_has_always_recommend',
 );
 
+has require_develop => (
+    is => 'ro', isa => Bool,
+    default => 1,
+);
+
 has default => (
     is => 'ro', isa => Bool,
     predicate => '_has_default',
@@ -73,8 +78,8 @@ around BUILDARGS => sub
     # pull these out so they don't become part of our prereq list
     my ($zilla, $plugin_name) = delete @{$args}{qw(zilla plugin_name)};
 
-    my ($feature_name, $description, $always_recommend, $default, $phase) =
-        delete @{$args}{qw(-name -description -always_recommend -default -phase)};
+    my ($feature_name, $description, $always_recommend, $require_develop, $default, $phase) =
+        delete @{$args}{qw(-name -description -always_recommend -require_develop -default -phase)};
     my ($type) = grep { defined } delete @{$args}{qw(-type -relationship)};
 
     my @other_options = grep { /^-/ } keys %$args;
@@ -107,6 +112,7 @@ around BUILDARGS => sub
         defined $feature_name ? ( name => $feature_name ) : (),
         defined $description ? ( description => $description ) : (),
         defined $always_recommend ? ( always_recommend => $always_recommend ) : (),
+        defined $require_develop ? ( require_develop => $require_develop ) : (),
         defined $default ? ( default => $default ) : (),
         defined $phase ? ( _prereq_phase => $phase ) : (),
         defined $type ? ( _prereq_type => $type ) : (),
@@ -125,7 +131,7 @@ around dump_config => sub
         # FIXME: YAML::Tiny does not handle leading - properly yet
         # (map { defined $self->$_ ? ( '-' . $_ => $self->$_ ) : () }
         (map { defined $self->$_ ? ( $_ => $self->$_ ) : () }
-            qw(name description always_recommend default)),
+            qw(name description always_recommend require_develop default)),
         phase => $self->_prereq_phase,
         type => $self->_prereq_type,
         prereqs => $self->_prereqs,
@@ -144,7 +150,7 @@ sub register_prereqs
             phase => 'develop',
         },
         %{ $self->_prereqs },
-    );
+    ) if $self->require_develop;
 
     return if not $self->always_recommend;
     $self->zilla->register_prereqs(
@@ -197,7 +203,7 @@ Dist::Zilla::Plugin::OptionalFeature - Specify prerequisites for optional featur
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -284,7 +290,14 @@ Defaults to the feature name, if not provided.
 If set with a true value, the prerequisites are added to the distribution's
 metadata as recommended prerequisites (e.g. L<cpanminus> will install
 recommendations with C<--with-recommends>, even when running
-non-interactively). Defaults to 0, but I recommend you turn this on.
+non-interactively). Defaults to false, but I recommend you turn this on.
+
+=item * C<-require_develop>
+
+If set with a true value, the prerequisites are added to the distribution's
+metadata as develop requires prerequisites (e.g. L<cpanminus> will install
+recommendations with C<--with-develop>, even when running
+non-interactively).  Defaults to true.
 
 =item * C<-default>
 
